pub async fn validate_api_token(
infra: &InfraContext<'_>,
token: &str,
) -> Result<(), Error>Expand description
Verify that token is still accepted by the site’s backend.
pub async fn validate_api_token(
infra: &InfraContext<'_>,
token: &str,
) -> Result<(), Error>Verify that token is still accepted by the site’s backend.